﻿namespace SampleCandleStorageTesting
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using Ecng.Common;
    using StockSharp.Algo;
    using StockSharp.Algo.Candles;
    using StockSharp.Algo.Indicators;
    using StockSharp.Algo.Indicators.Trend;
    using StockSharp.Algo.Strategies;
    using StockSharp.BusinessEntities;

    class SimpleStrategy : Strategy
    {
        private readonly CandleManager _candleManager;
        private decimal position = 0;

        public SimpleStrategy(CandleManager candleManager)            
        {
            _candleManager = candleManager;
        }

        protected override void OnStarting()
        {
            _candleManager.CandlesFinished += OnCandlesFinished;            

            base.OnStarting();
        }        

        private void OnCandlesFinished(CandleToken token, IEnumerable<Candle> candles)
        {
            foreach (var candle in candles)
            {
                if (position == 0 && candle.Time.Minute >= 0 && candle.Time.Minute < 30)
                    SendOrder(OrderDirections.Buy, this.Volume, candle);

                if (position != 0 && candle.Time.Minute >= 30)
                    SendOrder(OrderDirections.Sell, position, candle);
            }
        }

        private void SendOrder(OrderDirections direction, decimal volume, Candle _candle)
        {
            Position pos = Trader.GetPosition(Portfolio, Security);
            var priceLocal = Security.GetMarketPrice(direction);            

            priceLocal = _candle.ClosePrice + 1000 * (direction == OrderDirections.Buy ? 1 : -1);

            var order = this.CreateOrder(direction, priceLocal, volume);
            
            RegisterOrder(order);
            position += volume * (direction == OrderDirections.Buy ? 1 : -1);
        }        
    }
}